---
comments: true
title: Bump My Version
---

# Bump My Version

Bump My Version's purpose is to:

- Work as a part of an automated build system
- Manage project versioning through the project's development life cycle
  - Incrementing version numbers
  - Serializing version numbers
  - Parsing version numbers
  - Support SemVer, CalVer, and other versioning schemes
- Modify project files as part of the project's development life cycle
- Work with the project's source control system
  - Committing changes
  - Tagging releases
  - Reading version numbers from tags

## Installation

You can download and install the latest version of this software from the Python package index (PyPI) as follows:

```console
pip install --upgrade bump-my-version
```
<!--
## Jump to section

::: grid wide-gap

    ::: card-container

        ::: card-media

            ![Tutorials](assets/tutorial.jpg)

        ::: card-content

            [Tutorials](tutorials/getting-started.md)
            { .card-content-title }

            Follow along with our guides to learn how to use Bump My Version.

    ::: card-container

        ::: card-media

            ![Reference](assets/reference.jpg)

        ::: card-content

            [Reference](reference/)
            { .card-content-title }

            Consult the reference for specifics about the Bump My Version's configuration and commands.

    ::: card-container

        ::: card-media

            ![How-To's](assets/how-to.jpg)

        ::: card-content

            [How-To's](howtos/index.md)
            { .card-content-title }

            Need to get something done? Check out our how-to guides.

    ::: card-container

        ::: card-media

            ![Explanations](assets/explanations.jpg)

        ::: card-content

            [Explanations](explanation/index.md)
            { .card-content-title }

            Want to understand the library better? Read our explanations behind the design.
-->
